Jackal, the Boilerplate library for Django REST Framework
-------------------------------------------------------------

.. image:: https://badge.fury.io/py/django-jackal.svg
    :target: https://badge.fury.io/py/django-jackal

.. image:: https://github.com/joyongjin/Jackal/raw/master/images/jackal.jpg
    :width: 720px
    :align: center


**Jackal** is Boilerplate Library based on Django and Django REST Framework(DRF)
that help you easily implement the necessary features on your web backend server.

Installation
===============

.. code::

    pip install django-jackal


Document
============

See wiki_ for details.

.. _wiki: https://github.com/joyongjin/jackal/wiki

Test
============

.. code::

    python runtests.py tests
